@@ -1,6 +1,6 @@
 package Pcore::App::API::RPC::Hash;
 
-use Pcore -class, -rpc;
+use Pcore -class;
 use Crypt::Argon2;
 
 # http://argon2-cffi.readthedocs.io/en/stable/parameters.html
@@ -10,10 +10,10 @@ has argon2_time        => 3;        # ( is => 'ro', isa => PositiveInt, default
 has argon2_memory      => '64M';    # ( is => 'ro', isa => Str,         default => '64M' );
 has argon2_parallelism => 1;        # ( is => 'ro', isa => PositiveInt, default => 1 );
 
-sub API_create_hash ( $self, $cb, $str ) {
+sub API_create_hash ( $self, $cb, $str, $args = undef ) {
     my $salt = P->random->bytes(32);
 
-    my $hash = Crypt::Argon2::argon2i_pass( $str, $salt, $self->{argon2_time}, $self->{argon2_memory}, $self->{argon2_parallelism}, 32 );
+    my $hash = Crypt::Argon2::argon2i_pass( $str, $salt, $args->{argon2_time} // $self->{argon2_time}, $args->{argon2_memory} // $self->{argon2_memory}, $args->{argon2_parallelism} // $self->{argon2_parallelism}, 32 );
 
     $cb->( 200, $hash );
 
