@@ -4,7 +4,7 @@ use Pcore -class;
 use Pcore::Dist;
 use Pcore::API::SCM::Const qw[:ALL];
 
-with qw[Pcore::Core::CLI::Cmd];
+extends qw[Pcore::Core::CLI::Cmd];
 
 # CLI
 sub CLI ($self) {
