@@ -2,7 +2,7 @@ package Pcore::Dist::CLI::Setup;
 
 use Pcore -class;
 
-with qw[Pcore::Core::CLI::Cmd];
+extends qw[Pcore::Core::CLI::Cmd];
 
 sub CLI ($self) {
     return { abstract => 'setup ~/.pcore/pcore.ini', };
