@@ -4,7 +4,7 @@ use Pcore -role, -const;
 use Pcore::Handle::DBI::STH;
 use Pcore::Util::Scalar qw[is_ref is_plain_scalarref is_blessed_arrayref is_blessed_hashref];
 
-with qw[Pcore::Handle];
+with qw[Pcore::Handle::Base];
 
 requires qw[_get_schema_patch_table_query prepare quote];
 
