@@ -29,7 +29,7 @@ sub decompress ( $self, % ) {
 
         syswrite $temp, $self->buffer->$* or die;
 
-        my $proc = P->sys->run_proc( qq[js-beautify $js_beautify_args --replace "$temp"], win32_create_no_window => 1 );
+        my $proc = P->sys->run_proc1( qq[js-beautify $js_beautify_args --replace "$temp"], win32_create_no_window => 1 )->wait;
 
         $self->buffer->$* = P->file->read_bin( $temp->path )->$*;            ## no critic qw[Variables::RequireLocalizedPunctuationVars]
     }
@@ -124,7 +124,7 @@ sub run_js_hint ($self) {
 
     my $out_temp = $ENV->{TEMP_DIR} . 'tmp-jshint-' . int rand 99_999;
 
-    my $proc = P->sys->run_proc( qq[jshint  $js_hint_args "$in_temp" > "$out_temp"], win32_create_no_window => 1 );
+    my $proc = P->sys->run_proc1( qq[jshint  $js_hint_args "$in_temp" > "$out_temp"], win32_create_no_window => 1 )->wait;
 
     $jshint_output = P->file->read_lines($out_temp);
 
